@@ -552,18 +552,20 @@ def to_bipartite_graph(H):
     )
 
 
-def dict_to_hypergraph(hypergraph_dict, nodetype=None, edgetype=None):
+def dict_to_hypergraph(data, nodetype=None, edgetype=None, max_order=None):
     """
     A function to read a file in a standardized JSON format.
 
     Parameters
     ----------
-    hypergraph_dict: dict
+    data: dict
         A dictionary in the hypergraph JSON format
     nodetype: type, optional
-        type that the node IDs will be cast to
+        Type that the node IDs will be cast to
     edgetype: type, optional
-        type that the edge IDs will be cast to
+        Type that the edge IDs will be cast to
+    max_order: int, optional
+        Maximum order of edges to add to the hypergraph
 
     Returns
     -------
@@ -582,16 +584,16 @@ def dict_to_hypergraph(hypergraph_dict, nodetype=None, edgetype=None):
     """
     H = empty_hypergraph()
     try:
-        H._hypergraph.update(hypergraph_dict["hypergraph-data"])
+        H._hypergraph.update(data["hypergraph-data"])
     except KeyError:
         raise XGIError("Failed to get hypergraph data attributes.")
 
     try:
-        for id, dd in hypergraph_dict["node-data"].items():
+        for id, dd in data["node-data"].items():
             if nodetype is not None:
                 try:
                     id = nodetype(id)
-                except Exception as e:
+                except ValueError as e:
                     raise TypeError(
                         f"Failed to convert edge IDs to type {nodetype}."
                     ) from e
@@ -600,11 +602,13 @@ def dict_to_hypergraph(hypergraph_dict, nodetype=None, edgetype=None):
         raise XGIError("Failed to import node attributes.")
 
     try:
-        for id, edge in hypergraph_dict["edge-dict"].items():
+        for id, edge in data["edge-dict"].items():
+            if max_order and len(edge) > max_order + 1:
+                continue
             if edgetype is not None:
                 try:
                     id = edgetype(id)
-                except Exception as e:
+                except ValueError as e:
                     raise TypeError(
                         f"Failed to convert the edge with ID {id} to type {edgetype}."
                     ) from e
@@ -612,20 +616,30 @@ def dict_to_hypergraph(hypergraph_dict, nodetype=None, edgetype=None):
             if nodetype is not None:
                 try:
                     edge = {nodetype(n) for n in edge}
-                except Exception as e:
+                except ValueError as e:
                     raise TypeError(
                         f"Failed to convert nodes to type {nodetype}."
                     ) from e
             H.add_edge(edge, id)
+
     except KeyError as e:
         raise XGIError("Failed to import edge dictionary.") from e
 
     try:
+        if edgetype is None:
+            edge_data = {
+                key: val for key, val in data["edge-data"].items() if key in H.edges
+            }
+        else:
+            edge_data = {
+                edgetype(e): dd
+                for e, dd in data["edge-data"].items()
+                if edgetype(e) in H.edges
+            }
+
         set_edge_attributes(
             H,
-            hypergraph_dict["edge-data"]
-            if edgetype is None
-            else {edgetype(e): dd for e, dd in hypergraph_dict["edge-data"].items()},
+            edge_data,
         )
     except KeyError as e:
         raise XGIError("Failed to import edge attributes.") from e
