@@ -55,78 +55,7 @@ from xgi.exception import IDNotFound
 
 from . import edgestats, nodestats
 
-__all__ = ["nodestat_func", "edgestat_func", "EdgeStatDispatcher", "NodeStatDispatcher"]
-
-
-class StatDispatcher:
-    """For internal use; create :class:`NodeStat` or :class:`EdgeStat` objects.
-
-    See Also
-    --------
-    NodeStatDispatcher
-    EdgeStatDispatcher
-
-    """
-
-    def __init__(self, network, view, module, statsclass, multistatsclass):
-        self.net = network
-        self.view = view
-        self.module = module
-        self.statsclass = statsclass
-        self.multistatsclass = multistatsclass
-
-    def __getattr__(self, name):
-        try:
-            func = getattr(self.module, name)
-        except AttributeError as e:
-            raise AttributeError(f"Stat '{name}' not defined") from e
-        stat = self.statsclass(self.net, self.view, func)
-        self.__dict__[name] = stat
-        return stat
-
-    def multi(self, stats):
-        """Create a :class:`MultiStat` object.
-
-        See Also
-        --------
-        MultiNodeStat
-        MultiEdgeStat
-
-        Examples
-        -------
-        See the `tutorial
-        <https://github.com/ComplexGroupInteractions/xgi/blob/main/tutorials/Tutorial%206%20-%20Statistics.ipynb>`_.
-
-        """
-        return self.multistatsclass(self.net, self.view, stats)
-
-
-class EdgeStatDispatcher(StatDispatcher):
-    """For internal use; a :class:`StatDispatcher` for edge stats.
-
-    Examples
-    -------
-    See the `tutorial
-    <https://github.com/ComplexGroupInteractions/xgi/blob/main/tutorials/Tutorial%206%20-%20Statistics.ipynb>`_.
-
-    """
-
-    def __init__(self, network, view):
-        super().__init__(network, view, edgestats, EdgeStat, MultiEdgeStat)
-
-
-class NodeStatDispatcher(StatDispatcher):
-    """For internal use; a :class:`StatDispatcher` for node stats.
-
-    Examples
-    -------
-    See the `tutorial
-    <https://github.com/ComplexGroupInteractions/xgi/blob/main/tutorials/Tutorial%206%20-%20Statistics.ipynb>`_.
-
-    """
-
-    def __init__(self, network, view):
-        super().__init__(network, view, nodestats, NodeStat, MultiNodeStat)
+__all__ = ["nodestat_func", "edgestat_func", "dispatch_stat", "dispatch_many_stats"]
 
 
 class IDStat:
@@ -479,6 +408,32 @@ class MultiEdgeStat(MultiIDStat):
     statsmodule = edgestats
 
 
+_dispatch_data = {
+    "node": {
+        "module": nodestats,
+        "statclass": NodeStat,
+        "multistatclass": MultiNodeStat,
+    },
+    "edge": {
+        "module": edgestats,
+        "statclass": EdgeStat,
+        "multistatclass": MultiEdgeStat,
+    },
+}
+
+
+def dispatch_stat(kind, net, view, name):
+    try:
+        func = getattr(_dispatch_data[kind]["module"], name)
+    except AttributeError as e:
+        raise AttributeError(f"Stat '{name}' not defined") from e
+    return _dispatch_data[kind]["statclass"](net, view, func)
+
+
+def dispatch_many_stats(kind, net, view, stats):
+    return _dispatch_data[kind]["multistatclass"](net, view, stats)
+
+
 def nodestat_func(func):
     """Decorator that allows arbitrary functions to behave like :class:`NodeStat` objects.
 
@@ -528,7 +483,7 @@ def nodestat_func(func):
 
     >>> H.my_degree()
     Traceback (most recent call last):
-    AttributeError: stat "my_degree" not among available node or edge stats
+    AttributeError: my_degree is not a method of Hypergraph or a recognized NodeStat or EdgeStat
     >>> H.nodes.my_degree
     Traceback (most recent call last):
     AttributeError: Stat 'my_degree' not defined
